@@ -1395,8 +1395,8 @@ class FBRef:
             lineups[1].columns[0].split('(')[-1].replace(')','').strip() 
             if len(lineups)>0 else None
         )
-        match['Home Goals'] = int(scores[0].getText())
-        match['Away Goals'] = int(scores[1].getText())
+        match['Home Goals'] = int(scores[0].getText()) if scores[0].getText().isdecimal() else None
+        match['Away Goals'] = int(scores[1].getText()) if scores[1].getText().isdecimal() else None
         match['Home Ast'] = player_stats['Home']['Summary'][('Performance','Ast')].values[-1]
         match['Away Ast'] = player_stats['Away']['Summary'][('Performance','Ast')].values[-1]
         match['Home xG']   = (
